<?xml version="1.0"?>

<!--
*****************************************************************************
TransformLog.xslt
Copyright (C) 2003 Kinook (TM) Software, Inc.  All rights reserved.
http://www.kinook.com
Be sure to visit www.kinook.com for more handy utilities and tools, 
including Visual Build Pro, the build management tool for Windows and web
developers.

XSLT stylesheet for converting XML log files into HTML documents.
-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output encoding="UTF-8"/>

	<xsl:variable name="ALL" select="'1000000'"/>
	<xsl:variable name="ALL_BUILD" select="'012'"/>
	<xsl:variable name="ALL_STEP" select="'012356'"/>

	<!-- filter parameters passed by caller, default to no filtering -->
	<xsl:param name="BuildCount" select="$ALL"/>
	<xsl:param name="IncludeBuildStatus" select="$ALL_BUILD"/>
	<xsl:param name="IncludeStepStatus" select="$ALL_STEP"/>
	<xsl:param name="MaxStepOutput" select="$ALL"/>

	<xsl:template match="/">
		<html>
			<head>
			<title>Visual Build Pro Log Viewer</title>

			<script language="VBScript">
				Function launch(filename)
					' launch the given project in Visual Build Pro (displays security dialog)
					Set shell = CreateObject("WScript.Shell")
					shell.Run "VisBuildPro.exe """ + filename + """"
				End Function
			</script>

			<style type="text/css">
				.tablehdr { font-weight: bold }
			 </style>

			</head>

			<!-- tree of filtered build output by status and most recent builds -->
			<xsl:variable name="BuildStatusFilter" select="log/build[contains($IncludeBuildStatus, status/@code)][last() - position() &lt; $BuildCount]"/>

			<body>
				<center><h1>Visual Build Professional Log Viewer</h1></center>

				<!-- parameter info -->
				<h2>Parameters</h2>
				<p>
					Including build completion statuses: 
					<xsl:choose>
						<xsl:when test="$IncludeBuildStatus = $ALL_BUILD">
							<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'All'"/></xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="contains($IncludeBuildStatus, '0')">
								<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'Completed'"/></xsl:call-template>&#160;
							</xsl:if>
							<xsl:if test="contains($IncludeBuildStatus, '1')">
								<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'Failed'"/></xsl:call-template>&#160;
							</xsl:if>
							<xsl:if test="contains($IncludeBuildStatus, '2')">
								<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'Aborted'"/></xsl:call-template>&#160;
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
					<br/>
					Including recent builds:
					<xsl:choose>
						<xsl:when test="$BuildCount = $ALL">
							<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'All'"/></xsl:call-template>
						</xsl:when>
						<xsl:otherwise><b><xsl:value-of select="$BuildCount"/></b></xsl:otherwise>
					</xsl:choose>
					<br/>
					<xsl:if test="string-length($IncludeStepStatus) != 0">
						Including step build statuses: 
						<xsl:choose>
							<xsl:when test="$IncludeStepStatus = $ALL_STEP">
								<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'All'"/></xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="contains($IncludeStepStatus, '0')">
									<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'Completed'"/></xsl:call-template>&#160;
								</xsl:if>
								<xsl:if test="contains($IncludeStepStatus, '3')">
									<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'Skipped'"/></xsl:call-template>&#160;
								</xsl:if>
								<xsl:if test="contains($IncludeStepStatus, '6')">
									<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'Partial'"/></xsl:call-template>&#160;
								</xsl:if>
								<xsl:if test="contains($IncludeStepStatus, '1')">
									<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'Failed'"/></xsl:call-template>&#160;
								</xsl:if>
								<xsl:if test="contains($IncludeStepStatus, '2')">
									<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'Aborted'"/></xsl:call-template>&#160;
								</xsl:if>
								<xsl:if test="contains($IncludeStepStatus, '5')">
									<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="'MacroError'"/></xsl:call-template>&#160;
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
						<br/>
					</xsl:if>
					<xsl:if test="$MaxStepOutput != $ALL">Truncating step output at <b><xsl:value-of select="$MaxStepOutput"/></b> characters</xsl:if>
				</p>

				<!-- log summary -->
				<h2>Summary</h2>

				<table border="1" cellpadding="4" cellspacing="0" bordercolor="gray">
					<tr>
						<td class="tablehdr">ID</td>
						<td class="tablehdr">Filename</td>
						<td class="tablehdr">Context</td>
						<td class="tablehdr">Start</td>
						<td class="tablehdr">Finish</td>
						<td class="tablehdr">Elapsed</td>
						<td class="tablehdr">Status</td>
					</tr>
					<xsl:for-each select="$BuildStatusFilter">
						<tr>
							<td><a href="#{generate-id(.)}"><xsl:value-of select="position()"/></a></td>
							<td><a href='VBScript:launch("{name}")'><xsl:value-of select="name"/></a>&#160;</td>
							<td><xsl:value-of select="@context"/></td>
							<td><xsl:value-of select="@start"/></td>
							<td><xsl:value-of select="status/@finish"/></td>
							<td><xsl:value-of select="status/@elapsed"/></td>
							<td><xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="status"/></xsl:call-template></td>
						</tr>
					</xsl:for-each>
				</table>
				Notes: Click on build filename to launch in Visual Build Pro<br/>

				<!-- detail section -->
				<xsl:if test="string-length($IncludeStepStatus) != 0">
					Click on build number to jump to its detail
					<br/>
					<br/>

					<h2>Detail</h2>

					<xsl:for-each select="$BuildStatusFilter">
						<p>
							<p><h3><a name="{generate-id(.)}"></a>Build #<xsl:value-of select="position()"/>: <a href='jscript:launch("{name}")'><xsl:value-of select="name"/></a>
							(<xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="status"/></xsl:call-template>)</h3></p>

							<table border="1" cellpadding="4" cellspacing="0" bordercolor="gray">
								<tr>
									<td class="tablehdr">Name</td>
									<td class="tablehdr">Action</td>
									<td class="tablehdr">Start</td>
									<td class="tablehdr">Status</td>
									<xsl:if test="$MaxStepOutput != '0'"><td class="tablehdr">Output</td></xsl:if>
								</tr>
								<xsl:for-each select="step[contains($IncludeStepStatus, status/@code)]"><!-- filter by step status -->
									<tr>
										<td><xsl:value-of select="name"/></td>
										<td><xsl:value-of select="@action"/></td>
										<td><xsl:value-of select="@start"/></td>
										<td><xsl:call-template name="StatusColor"><xsl:with-param name="StatusString" select="status"/></xsl:call-template></td>
										<xsl:if test="$MaxStepOutput != '0'"><td><pre><xsl:value-of select="substring(output, 0, $MaxStepOutput)"/>&#160;</pre></td></xsl:if>
									</tr>
								</xsl:for-each>
							</table>
						</p>
						<br/>
					</xsl:for-each>
				</xsl:if>

			</body>
		</html>
	</xsl:template>

	<!-- template to colorize build/step status based on its content -->
	<xsl:template name="StatusColor">
		<xsl:param name="StatusString"/><b>
		<xsl:choose>
			<xsl:when test="$StatusString = 'All'"><xsl:value-of select="$StatusString"/></xsl:when>
			<xsl:when test="contains($StatusString, 'Completed')"><font color="limegreen"><xsl:value-of select="$StatusString"/></font></xsl:when>
			<xsl:when test="$StatusString = 'Skipped'"><font color="deeppink"><xsl:value-of select="$StatusString"/></font></xsl:when>
			<xsl:when test="$StatusString = 'Partial'"><font color="darkgray"><xsl:value-of select="$StatusString"/></font></xsl:when>
			<xsl:otherwise><font color="red"><xsl:value-of select="$StatusString"/></font></xsl:otherwise>
		</xsl:choose></b>
	</xsl:template>

</xsl:stylesheet>
